# Configuring Authentication to SAP LeanIX APIs in Postman
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-authentication-to-sap-leanix-apis-in-postman#prerequisites)
  * [Procedure](https://help.sap.com/docs/leanix/ea/configuring-authentication-to-sap-leanix-apis-in-postman#procedure)


Configure OAuth 2.0 authentication to SAP LeanIX APIs for a collection in Postman. The configuration applies to both REST and GraphQL protocols.
[Postman![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.postman.com%2F "https://www.postman.com/") is an API platform for building and using APIs. For more information, refer to the Postman documentation.
